/*
 * Copyright (c) 2004-2005 Northwestern University.
 *                         NuCAD Group.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*
 * fplan.h - Interface for floorplanning.
 *
 * Authors: Hai Zhou, haizhou@ece.northwestern.edu
 *          Jia Wang, jwa112@ece.northwestern.edu
 *
 */

#ifndef FPLAN_H
#define FPLAN_H

#include "cost.h"
#include "nets.h"

namespace fplan
{

// floorplan interface
struct fplan_i
{
	virtual size_t get_num_modules() = 0;
	virtual misc::dbl_pair get_shape() = 0;
	virtual misc::dbl_pair get_centers(size_t ids[], misc::dbl_pair centers[]) = 0;
	virtual misc::dbl_pair get_physical_info(
		size_t ids[], misc::dbl_pair centers[],
		misc::dbl_pair lls[], misc::dbl_pair urs[],
		size_t rotated[], misc::dbl_pair rotated_shapes[]) = 0;

	cost_ptr area_cost();
	cost_ptr fixed_cost(double w, double h, bool rotate = true);
	cost_ptr square_cost();

	// assume ids are 0, 1, ...
	cost_ptr HPWL_cost(const module_nets_t &mnets, size_t np, const misc::dbl_pair pins[]);
	cost_ptr QPWL_cost(const module_nets_t &mnets, size_t np, const misc::dbl_pair pins[]);

protected:
	~fplan_i() {} // no delete
}; // struct fplan_i

} // namespace fplan

#endif // FPLAN_H
