/*
 * Copyright (c) 2004-2005 Northwestern University.
 *                         NuCAD Group.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

/*
 * gsrc.h - GSRC benchmark interface.
 *
 * Authors: Jia Wang, jwa112@ece.northwestern.edu
 *
 */

#ifndef GSRC_H
#define GSRC_H

#include "../misc/geometry.h"

namespace gsrc
{

struct signal_t;

struct module_t
{
	std::string name;
	std::vector<signal_t *> nets;
	double w, h; // weight/height for blocks and ratio for terminals
	double x, y; // center position
	int id;
}; // struct module_t

struct signal_t
{
	std::vector<module_t *> pins;
}; // struct signal_t

struct detailed_signal_t
{
	typedef std::pair<module_t *, misc::dbl_pair> pin_t;
	std::vector<pin_t> pins;
}; // struct detailed_signal_t

// read a GSRC benchmark, return # of blocks
int read_gsrc(const std::string &gsrc,
	std::vector<module_t> &modules,
	std::vector<signal_t> &signals,
	std::vector<detailed_signal_t> *detailed = 0,
	misc::dbl_pair *shape = 0);

} // namespace gsrc

#endif // GSRC_H
